const playwright = require('playwright-aws-lambda')
const AWS = require('aws-sdk');
const s3 = new AWS.S3()

exports.handler = async (event) => {
    let browser
    let pdfOutput
    const bucketName = 'pdfgeneratorbucketpdf'
    console.log(event)

    try {
        let context
        browser = await playwright.launchChromium({headless: false})
        context = await browser.newContext({
            ignoreHTTPSErrors: true, timezoneId: event.queryStringParameters.timezoneid,
        })

        const page = await context.newPage()
        await page.goto(event.queryStringParameters.url, {timeout: 10000})
        pdfOutput = await page.pdf({
            printBackground: true, scale: 1.2, margin: {top: "50px", bottom: "50px"},
        })
    } finally {
        if (browser) {
            await browser.close()
        }
    }

    let pdfUrl

    try {
        await s3.upload({Key: event.queryStringParameters.fileName, Bucket: bucketName, Body: pdfOutput}).promise();
        pdfUrl = s3.getSignedUrl('getObject', {
            Bucket: bucketName, Key: event.queryStringParameters.fileName, Expires: 3600
        })
    } catch (err) {
        console.error(`Uploading PDF to the bucket: "${bucketName}" failed`, err)
        throw err
    }

    console.log(`Signed URL: ${pdfUrl}`)
    return {data: pdfUrl}

// local return for debuging
    // return {
    //     statusCode: 200,
    //     headers: {
    //         "Content-Type": "application/pdf",
    //         "Content-Disposition": `attachment; filename=${event.fileName}`
    //     },
    //     body: pdfOutput.toString("base64"),
    //     isBase64Encoded: true
    // }
}
